%global _python_bytecompile_extra 0

%global major 7
%define libname %mklibname lld %major
%define devname %mklibname -d lld
#%%global rc_ver 2
%global baserelease 3
%global lld_srcdir lld-%{version}%{?rc_ver:rc%{rc_ver}}.src
%global maj_ver 11
%global min_ver 0
%global patch_ver 1

# Don't include unittests in automatic generation of provides or requires.
%global __provides_exclude_from ^%{_libdir}/lld/.*$
%global __requires_exclude ^libgtest.*$



Name:		lld
Version:	%{maj_ver}.%{min_ver}.%{patch_ver}
Release:	%mkrel %{baserelease}%{?rc_ver:.rc%{rc_ver}}.2
Summary:	The LLVM Linker
Group:		Development/Tools

License:	NCSA
URL:		http://llvm.org
Source0:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}%{?rc_ver:-rc%{rc_ver}}/%{lld_srcdir}.tar.xz
Source1:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}%{?rc_ver:-rc%{rc_ver}}/%{lld_srcdir}.tar.xz.sig
Source2:	tstellar-gpg-key.asc
Source3:	run-lit-tests
Source4:	lit.lld-test.cfg.py

ExcludeArch:	s390x

Patch0:		0001-CMake-Check-for-gtest-headers-even-if-lit.py-is-not-.patch
Patch1:		0001-Revert-lld-Initial-commit-for-new-Mach-O-backend.patch

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires: cmake
BuildRequires:	ninja-build
BuildRequires: llvm-devel = %{version}
BuildRequires:	llvm-test = %{version}
BuildRequires: ncurses-devel
BuildRequires: zlib-devel

# For make check:
BuildRequires: python3-rpm-macros
BuildRequires: python3-lit
BuildRequires:	llvm-googletest = %{version}

# For gpg source verification
BuildRequires:	gnupg2

# For /sbin/alternatives:
Requires(post): chkconfig
Requires(preun): chkconfig

Requires: %libname = %{version}-%{release}

%description
The LLVM project linker.

%package -n %devname
Group: Development/C
Summary:	Libraries and header files for LLD
Requires: %libname = %{version}-%{release}
# lld tools are referenced in the cmake files, so we need to add lld as a
# dependency.
Requires: %{name}%{?_isa} = %{version}-%{release}

%description -n %devname
This package contains library and header files needed to develop new native
programs that use the LLD infrastructure.

%package -n %libname
Summary:	LLD shared libraries
Group: System/Libraries

%description -n %libname
Shared libraries for LLD.

%package test
Summary: LLD regression tests
Requires:	%{name}%{?_isa} = %{version}-%{release}
Requires:	python3-lit
Requires:	llvm-test(major) = %{maj_ver}
Requires:	%libname = %{version}-%{release}

%description test
LLVM regression tests.

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%setup -q -n %{lld_srcdir}

%patch0 -p1 -b .gtest-fix
# Remove the MachO backend since it doesn't seem to work on big-endian hosts.
%ifarch s390x
%patch1 -p2 -b .remove-MachO
%endif



%build
# FC compatibility:
%global _vpath_builddir %{_target_platform}

%cmake \
	-GNinja \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DLLVM_DYLIB_COMPONENTS="all" \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DPYTHON_EXECUTABLE=%{__python3} \
	-DLLVM_INCLUDE_TESTS=ON \
	-DLLVM_MAIN_SRC_DIR=%{_datadir}/llvm/src \
	-DLLVM_EXTERNAL_LIT=%{_bindir}/lit \
	-DLLVM_LIT_ARGS="-sv \
	--path %{_libdir}/llvm" \
%if 0%{?__isa_bits} == 64
	-DLLVM_LIBDIR_SUFFIX=64
%else
	-DLLVM_LIBDIR_SUFFIX=
%endif

%__cmake --build  %{_vpath_builddir}

# Build the unittests so we can install them.
#cmake_build --target lld-test-depends

%install

%global lit_cfg test/%{_arch}.site.cfg.py
%global lit_unit_cfg test/Unit/%{_arch}.site.cfg.py
%global lit_lld_test_cfg_install_path %{_datadir}/lld/lit.lld-test.cfg.py

# Generate lit config files.  Strip off the last line that initiates the
# test run, so we can customize the configuration.
head -n -1 %{_target_platform}/test/lit.site.cfg.py >> %{lit_cfg}
head -n -1 %{_target_platform}/test/Unit/lit.site.cfg.py >> %{lit_unit_cfg}

# Patch lit config files to load custom config:
for f in %{lit_cfg} %{lit_unit_cfg}; do
  echo "lit_config.load_config(config, '%{lit_lld_test_cfg_install_path}')" >> $f
done

# Install test files
install -d %{buildroot}%{_datadir}/lld/src
cp %{SOURCE4} %{buildroot}%{_datadir}/lld/

# The various tar options are there to make sur the archive is the same on 32 and 64 bit arch, i.e.
# the archive creation is reproducible. Move arch-specific content out of the tarball
mv %{lit_cfg} %{buildroot}%{_datadir}/lld/src/%{_arch}.site.cfg.py
mv %{lit_unit_cfg} %{buildroot}%{_datadir}/lld/src/%{_arch}.Unit.site.cfg.py
tar --sort=name --mtime='UTC 2020-01-01' -c test/ | gzip -n > %{buildroot}%{_datadir}/lld/src/test.tar.gz

install -d %{buildroot}%{_libexecdir}/tests/lld
cp %{SOURCE3} %{buildroot}%{_libexecdir}/tests/lld

# Install unit test binaries
install -d %{buildroot}%{_libdir}/lld/
cp -R %{_target_platform}/unittests %{buildroot}%{_libdir}/lld/
rm -rf `find %{buildroot}%{_libdir}/lld/ -iname '*make*'`

# Install gtest libraries
cp %{_target_platform}/%{_lib}/libgtest*so* %{buildroot}%{_libdir}/lld/

# Install libraries and binaries
DESTDIR="%{buildroot}" %__cmake --install "%{_vpath_builddir}"

# Required when using update-alternatives:
# https://docs.fedoraproject.org/en-US/packaging-guidelines/Alternatives/
touch %{buildroot}%{_bindir}/ld

%post
%{_sbindir}/update-alternatives --install %{_bindir}/ld ld %{_bindir}/ld.lld 1

%postun
if [ $1 -eq 0 ] ; then
  %{_sbindir}/update-alternatives --remove ld %{_bindir}/ld.lld
fi

%check

# armv7lhl tests disabled because of arm issue, see https://koji.fedoraproject.org/koji/taskinfo?taskID=33660162
%ifnarch %{arm}
%__cmake --build  %{_vpath_builddir} --target check-lld
%endif


%files
%license LICENSE.TXT
%ghost %{_bindir}/ld
%{_bindir}/lld*
%{_bindir}/ld.lld
%{_bindir}/ld64.lld
%{_bindir}/wasm-ld

%files -n %devname
%{_includedir}/lld
%{_libdir}/liblld*.so
%{_libdir}/cmake/lld/

%files -n %libname
%{_libdir}/liblld*.so.*

%files test
%{_libexecdir}/tests/lld/
%{_libdir}/lld/
%{_datadir}/lld/src/test.tar.gz
%{_datadir}/lld/src/%{_arch}.site.cfg.py
%{_datadir}/lld/src/%{_arch}.Unit.site.cfg.py
%{_datadir}/lld/lit.lld-test.cfg.py


%changelog
* Thu Jan 07 2021 tv <tv> 11.0.1-3.2.mga8
+ Revision: 1669445
- LLVM 11.0.1 final

* Wed Dec 23 2020 tv <tv> 11.0.1-2.rc2.2.mga8
+ Revision: 1663058
- llvm 11.0.1-rc2

* Wed Dec 02 2020 tv <tv> 11.0.1-1.rc1.2.mga8
+ Revision: 1651722
- llvm 11.0.1-rc1

* Wed Nov 25 2020 tv <tv> 11.0.0-3.2.mga8
+ Revision: 1649295
- 11.0.0

* Fri Oct 16 2020 ghibo <ghibo> 10.0.1-2.mga8
+ Revision: 1636367
- Rebuild to fix weird package release number

* Thu Oct 08 2020 akien <akien> 10.0.1-1.2.mga8
+ Revision: 1632801
- Version 10.0.1

* Thu Sep 10 2020 tv <tv> 10.0.0-3.2.mga8
+ Revision: 1624176
- fix file deps

* Mon Jul 20 2020 tv <tv> 10.0.0-3.1.mga8
+ Revision: 1607465
- adjust for %%cmake_install being different from FC's one
- adjust for %%cmake_build being different from FC's one
- Use generic cmake macros
- Use Ninja as build system
- Remove chrpath dependency

* Mon Jul 20 2020 tv <tv> 10.0.0-2.mga8
+ Revision: 1607425
- Make test archive arch-independent

* Tue Mar 24 2020 tv <tv> 10.0.0-1.mga8
+ Revision: 1559499
- 10.0.0 final

* Thu Mar 19 2020 tv <tv> 10.0.0-0.5.rc5.mga8
+ Revision: 1558095
- 10.0.0 rc5

* Sun Mar 15 2020 tv <tv> 10.0.0-0.4.rc4.mga8
+ Revision: 1556555
- 10.0.0 rc4
- enable verifying sources with latest rpm-mageia-setup

* Thu Mar 05 2020 tv <tv> 10.0.0-0.3.rc3.mga8
+ Revision: 1554130
- 10.0.0 RC3

* Thu Mar 05 2020 tv <tv> 10.0.0-0.2.rc2.mga8
+ Revision: 1554127
- 10.0.0 RC3
- 10.0.0 RC2

* Thu Feb 13 2020 tv <tv> 10.0.0-0.1.1.rc1.mga8
+ Revision: 1512927
- fix deps

* Wed Feb 12 2020 tv <tv> 10.0.0-0.1.rc1.mga8
+ Revision: 1510128
- disable brp-python-bytecompile automagic
- 10.0.0 rc1
+ wally <wally>
- build with new cmake macros

* Sat Sep 21 2019 tv <tv> 9.0.0-1.mga8
+ Revision: 1444191
- 9.0.0 Release

* Tue Sep 17 2019 tv <tv> 9.0.0-0.1.rc3.mga8
+ Revision: 1442776
- drop BR on python2-lit
- 9.0.0-rc3 Release
- touch /usr/bin/ld as required by the packaging guidelines for
  update-alternatives
- Add update-alternative for ld

* Sat Apr 13 2019 tv <tv> 8.0.0-2.mga7
+ Revision: 1389641
- 8.0.0
- ignore test failure for now

* Fri Feb 01 2019 tv <tv> 7.0.1-2.mga7
+ Revision: 1362216
- Fix lld + annobin integration & Setup basic CI tests
- 7.0.1

* Mon Nov 26 2018 tv <tv> 7.0.0-1.mga7
+ Revision: 1334867
- fix build on !64bit
- BR python2-lit for testsuite
- "fix" underlinking
- further fix unittests linking
- fix unittests linking
- fix tools linking
- imported package lld

